@@ -1,12 +1,13 @@
-from ompl import Planner, Algorithm, set_ompl_random_seed
 import numpy as np
-import time
+
+from ompl import Algorithm, Planner, set_ompl_random_seed
 
 
 def is_valid(x) -> bool:
     r = np.linalg.norm(np.array(x) - np.ones(2) * 0.5)
     return bool(r > 0.35)
 
+
 start = np.array([0.1, 0.1])
 goal = np.array([0.9, 0.9])
 
