@@ -1,7 +1,9 @@
 import matplotlib.pyplot as plt
+import numpy as np
+import pytest
 from common import IsValid, ProblemDef, Trajectory
 
-from ompl import Planner, set_ompl_random_seed
+from ompl import InvalidProblemError, Planner, set_ompl_random_seed
 
 set_ompl_random_seed(0)
 
@@ -34,5 +36,21 @@ def test_planner(visualize: bool = False):
         plt.show()
 
 
+def test_invalid_problem():
+    is_valid = IsValid(0)
+    pdef = ProblemDef()
+    planner = Planner(pdef.lb, pdef.ub, is_valid, pdef.n_max_call, pdef.motion_step_box)
+    # out of box
+    with pytest.raises(InvalidProblemError):
+        planner.solve(np.ones(2) * 10, pdef.goal)
+
+    with pytest.raises(InvalidProblemError):
+        planner.solve(pdef.start, np.ones(2) * 10)
+
+    with pytest.raises(InvalidProblemError):
+        x_invalid = np.array([0.5, 0.8])
+        planner.solve(pdef.start, x_invalid)
+
+
 if __name__ == "__main__":
     test_planner(visualize=True)
